package com.gic.finance.web.controller;

import com.gic.finance.dto.CashWithdrawalDTO;
import com.gic.finance.qo.CashWithdrawalQueryListQO;
import com.gic.finance.service.CashWithdrawalApiService;
import com.gic.finance.web.vo.CashWithdrawalDetailVO;
import com.gic.finance.web.vo.CashWithdrawalListVO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.finance.dto.PayAccountDTO;
import com.gic.finance.service.PayAccountApiService;

/**
 * 提现管理
 * @ClassName: CashWithdrawalController 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/29 3:33 PM 
 */
@RestController
@RequestMapping("/cash-withdrawal")
public class CashWithdrawalController {
    private static Logger LOGGER = LoggerFactory.getLogger(CashWithdrawalController.class);

    @Autowired
    private PayAccountApiService payAccountApiService;
    @Autowired
    private CashWithdrawalApiService cashWithdrawalApiService;

    /**
     * 新增打款账户
     * @Title: savePayAccount 
     * @Description:
      * @author guojuxing
     * @param dto 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/save-pay-account")
    public RestResponse savePayAccount(PayAccountDTO dto) {
        return ResultControllerUtils.commonResult(payAccountApiService.save(dto));
    }

    @RequestMapping("/edit-pay-account")
    public RestResponse editPayAccount(PayAccountDTO dto) {
        return ResultControllerUtils.commonResult(payAccountApiService.update(dto));
    }

    /**
     * 下移排序
     * @Title: downSort 
     * @Description:
      * @author guojuxing
     * @param id 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/down-sort")
    public RestResponse downSort(Integer id) {
        return ResultControllerUtils.commonResult(payAccountApiService.downSort(id));
    }

    @RequestMapping("/up-sort")
    public RestResponse upSort(Integer id) {
        return ResultControllerUtils.commonResult(payAccountApiService.upSort(id));
    }

    /**
     * 拖拽排序
     * @Title: setSort 
     * @Description:
      * @author guojuxing
     * @param id 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/set-sort")
    public RestResponse setSort(Integer id, Integer sortValue) {
        return ResultControllerUtils.commonResult(payAccountApiService.setSort(id, sortValue));
    }

    @RequestMapping("/delete-pay-account")
    public RestResponse deletePayAccount(Integer id) {
        return ResultControllerUtils.commonResult(payAccountApiService.delete(id));
    }

    /**
     * 详情
     * @Title: getDetail 
     * @Description:
      * @author guojuxing
     * @param id 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/get-pay-account-detail")
    public RestResponse getPayAccountDetail(Integer id) {
        return ResultControllerUtils.commonResult(payAccountApiService.getById(id));
    }

    /**
     * 查询列表数据
     * @Title: listPayAccount 
     * @Description:
      * @author guojuxing  
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/list-pay-account")
    public RestResponse listPayAccount() {
        return ResultControllerUtils.commonResult(payAccountApiService.listPayAccount());
    }

    /**
     * 提现管理列表
     * @Title: listCashWithdrawal 
     * @Description:
      * @author guojuxing
     * @param params 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/list-cash-withdrawal")
    public RestResponse listCashWithdrawal(CashWithdrawalQueryListQO params) {
        return ResultControllerUtils.commonPageResult(cashWithdrawalApiService.listCashWithdrawalPage(params),
                CashWithdrawalListVO.class);
    }

    /**
     * 审批通过
     * @Title: approval 
     * @Description:
      * @author guojuxing
     * @param id 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/approval")
    public RestResponse approval(Integer id) {
        return ResultControllerUtils.commonResult(cashWithdrawalApiService.approval(id));
    }

    @RequestMapping("/save")
    public RestResponse save(CashWithdrawalDTO dto) {
        return ResultControllerUtils.commonResult(cashWithdrawalApiService.cashWithdrawalOfServiceProvider(dto));
    }

    /**
     * 驳回
     * @Title: reject 
     * @Description:
      * @author guojuxing
     * @param id
     * @param rejectReason 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/reject")
    public RestResponse reject(Integer id, String rejectReason) {
        return ResultControllerUtils.commonResult(cashWithdrawalApiService.reject(id, rejectReason));
    }

    /**
     * 打款
     * @Title: pay 
     * @Description:
      * @author guojuxing
     * @param id
     * @param payId 打款户ID
     * @param bankSerialNumber  银行转账流水号
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/pay")
    public RestResponse pay(Integer id, Integer payId, String bankSerialNumber) {
        return ResultControllerUtils.commonResult(cashWithdrawalApiService.pay(id, payId, bankSerialNumber));
    }

    @RequestMapping("/get-detail")
    public RestResponse getDetail(Integer id) {
        return ResultControllerUtils.commonResultOne(cashWithdrawalApiService.getDetail(id), CashWithdrawalDetailVO.class);
    }
}
